@@ -1,3 +1,22 @@
+/*
+ * Copyright (C) 2009, Nokia <ivan.frade@nokia.com>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */
+
 #include "ttl_loader.h"
 #include <glib/gstdio.h>
 
@@ -29,6 +48,7 @@
 
 #define DSC_ONTOLOGY DSC_PREFIX "Ontology"
 #define DSC_TITLE DSC_PREFIX "title"
+#define DSC_DESCRIPTION DSC_PREFIX "description"
 #define DSC_AUTHOR DSC_PREFIX "author"
 #define DSC_EDITOR DSC_PREFIX "editor"
 #define DSC_CONTRIBUTOR DSC_PREFIX "contributor"
@@ -279,6 +299,8 @@ load_description (OntologyDescription *desc,
 		g_assert (!g_strcmp0 (turtle_object, DSC_ONTOLOGY));
 	} else if (!g_strcmp0 (turtle_predicate, DSC_TITLE)) {
 		desc->title = g_strdup (turtle_object);
+	} else if (!g_strcmp0 (turtle_predicate, DSC_DESCRIPTION)) {
+		desc->description = g_strdup (turtle_object);
 	} else if (!g_strcmp0 (turtle_predicate, DSC_UPSTREAM)) {
 		desc->upstream = g_strdup (turtle_object);
 	} else if (!g_strcmp0 (turtle_predicate, DSC_AUTHOR)) {
